#!/usr/bin/env python3


class Job:
    """a job object"""

    def __init__(
        self,
        url,
        title="",
        organisation="",
        description="",
        requirements="",
        due_date=None,
        post_date=None,
    ):
        self.url = url
        self.title = title
        self.organisation = organisation
        self.description = description
        self.requirements = requirements
        self.due_date = due_date
        self.post_date = post_date

    def __str__(self):
        url_split = self.url.split("/")
        url_last_part = url_split[-2] + "/" + url_split[-1]
        if self.title != "" and self.organisation != "":
            return f"{url_last_part} {self.title}, {self.organisation}"
        elif self.title != "":
            return f"{url_last_part} {self.title}"
        return self.url_last_part


class JobList:
    """a list of jobs"""

    def __init__(self, jobs: list = []):
        self.jobs = jobs

    def add_job(self, *args, **kwargs):
        """add a job to the list"""
        self.jobs.append(Job(*args, **kwargs))

    def remove_jobs_with_url(self, urls: list):
        """removes jobs with URLs in the given list"""
        new_jobs = []
        for job in self.jobs:
            if job.url not in urls:
                new_jobs.append(job)
        self.jobs = new_jobs

    def get_urls(self):
        """get a list of all job urls"""
        return [job.url for job in self.jobs]

    def __str__(self):
        return "\n".join(str(job) for job in self.jobs) if self.jobs else ""
