#!/usr/bin/env python3

import json
from pathlib import Path
import urllib3
import requests
from bs4 import BeautifulSoup
from backends import JobList

urllib3.disable_warnings()

INFOPARK_HEADERS = {"X-Requested-With": "XMLHttpRequest"}
SAVED_FILENAME = "jobs.json"


def get_saved_urls():
    """return a list of job urls stored locally"""
    saved_file = Path(SAVED_FILENAME)
    # if file exist
    if saved_file.is_file():
        with open(saved_file) as f:
            return json.load(f)
    return []


def save_urls(urls):
    """save the list of job urls locally to a json file"""
    saved_file = Path(SAVED_FILENAME)
    with open(saved_file, "w") as f:
        f.write(json.dumps(urls))


if __name__ == "__main__":
    url = "https://infopark.in/companies/job-search?page=1"
    joblist = JobList()

    while url is not None:
        r = requests.get(url, headers=INFOPARK_HEADERS, verify=False, timeout=10)
        data = r.json()
        soup = BeautifulSoup(data["all_jobs"], "html.parser")

        # find url to next page
        rel_next = soup.find_all(attrs={"rel": "next"})
        if rel_next:
            url = rel_next[0]["href"]
        else:
            url = None

        for row in soup.table.tbody.find_all("tr"):
            joblist.add_job(
                url=row.contents[7].a["href"],
                title=row.contents[1].text,
                organisation=row.contents[3].text,
            )

        saved_urls = get_saved_urls()
        joblist.remove_jobs_with_url(saved_urls)
        save_urls(saved_urls + joblist.get_urls())
        if joblist.jobs != []:
            print(joblist, flush=True)
